autowisp.database.data_model.input_master_types module — AutoWISP documentation

# autowisp.database.data_model.input_master_types module

## Class Inheritance Diagram

Define class specifying what masters are needed for what step/image type.

class autowisp.database.data_model.input_master_types.InputMasterTypes(**kwargs)

  Bases: `DataModelBase`

  The table describing the prerequisites for a step to run

  config_name

    The name of the configuration parameter that specifies the master when running the specified step.

  id

    A unique identifier for each row.

  image_type
  image_type_id

    The image type for which this prerequisite applies.

  master_type
  master_type_id

    The master type required for the step to run.

  optional

    Can processing by the given step of the given types of images can proceed if the given type of master is not found?

  step
  step_id

    The step for which this prerequisite applies.

  timestamp

    When record was last changed